==> databot-portable-windows-v3.7.8.zip: databot-portable-windows/app/alembic/env.py <==
from logging.config import fileConfig

from sqlalchemy import engine_from_config
from sqlalchemy import pool

from alembic import context
from shared.models import Base
import os

is_portable = os.getenv("IS_PORTABLE") == 'true'

if is_portable:
    DATABASE_URL = f'postgresql+pg8000://postgres@127.0.0.1:5432/databot'
else:
    DATABASE_URL = (
        f"postgresql+pg8000://{os.getenv('DATABOT_DB_USER')}:{os.getenv('DATABOT_DB_PASS')}@"
        f"{os.getenv('DATABOT_DB_HOST')}:{os.getenv('DATABOT_DB_PORT')}/{os.getenv('DATABOT_DB_DATABASE')}"
    )


# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# Update the SQLAlchemy URL dynamically
config.set_main_option('sqlalchemy.url', DATABASE_URL)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section, {}),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> databot-portable-windows-v3.10.3.zip: databot-portable-windows/app/alembic/env.py <==
from logging.config import fileConfig
import os

from sqlalchemy.engine import URL
from sqlalchemy import engine_from_config
from sqlalchemy import pool
from alembic import context
from shared.models import Base
from shared.security_utils import getenv_secret


is_portable = getenv_secret("IS_PORTABLE") == 'true'

if is_portable:
    DATABASE_URL = f'postgresql+pg8000://postgres@127.0.0.1:5432/databot'
else:
    db_url = URL.create(
        drivername="postgresql+pg8000",
        username=getenv_secret("DATABOT_DB_USER"),
        password=getenv_secret("DATABOT_DB_PASS"),
        host=getenv_secret("DATABOT_DB_HOST"),
        port=int(getenv_secret("DATABOT_DB_PORT")),
        database=getenv_secret("DATABOT_DB_DATABASE"),
    )
    DATABASE_URL = db_url.render_as_string(hide_password=False)


# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# Update the SQLAlchemy URL dynamically
config.set_main_option('sqlalchemy.url', DATABASE_URL.replace('%', '%%'))

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section, {}),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
